#setwd()
ReadPrepped <- function (fn.rel) {
  fn <- paste0('~/data/1_prepped/', fn.rel)
 readRDS(fn)
}

# Single-number Statistics for the Estimation Datasets
# -------------------------------------------------------------------------
library(dplyr)

source('prep_abr.R')
d$jr.case1[d$city=="Madrid"] <- FALSE # Do not exclude Madrid due to joint reporting (was jr.case=1)
default.data <- CenterLogs(d)
default.data$jr.case1[default.data$city=="Madrid"] <- FALSE # Do not exclude Madrid due to joint reporting (was jr.case=1)
source('subsetting_functions.R')

source('prep_inger.R')

DescribeData <- function(df) {
  vars <- intersect(c('city.de.harm.j', 'country.iso3', 'year'), names(df))
  df %>%
    mutate(number = 1:nrow(.)) %>%
    select(one_of(c(vars, 'number'))) %>%
    gather(variable, value, everything()) %>%
    group_by(variable) %>%
    summarise(ndistinct = n_distinct(value))
}


# Table: Descriptive Statistics Goethe Dataset
# -------------------------------------------------------------------------
fo.tab.desc <- 'tab-descriptives_goethe.tex'

library(xtable)
library(dplyr)
library(tidyr)
library(stringr)

# # g(oethe) l(ong)
# gl <- ReadPrepped('goethe/digitized/goethe_institute_year.rds') %>%
#     select(country.iso3, city.de.harm.j, year, variable, value) %>%
#     mutate(year = as.integer(as.character(year)))
# 
# #var(iables) of interest
# vars <- as.data.frame(matrix(c(
#     'exams', 'Exams',
#     'students', 'Students',
#     'courses.units.h', 'Course Hours',
#     # 'courses', 'Courses',
#     'teachers', 'Teachers'),
#     ncol = 2, byrow = TRUE))
# names(vars) = c('variable', 'Variable')
# 
# # My Summary (function)
# MySummary <- . %>%
#     summarise('From'      = min(year),
#               'To'        = max(year),
#               'Countries' = length(unique(country.iso3)),
#               'Min.'      = min(value),
#               'Median'    = median(value),
#               'Mean'      = mean(value),
#               'Max.'      = max(value))
# 
# # su(mmary) var(iable)s
# su.vars <- gl %>%
#     filter(variable %in% vars$var) %>%
#     mutate(value = as.numeric(as.character(value))) %>%
#     filter(!is.na(value)) %>%
#     group_by(variable) %>%
#     MySummary() %>%
#     right_join(vars) %>%
#     select(Variable, everything(), -variable)
# 
# 
# # su(mmary) (participation in) Ger(many)
# su.ger <- ReadPrepped('goethe/digitized_in_Germany/goethe_in_Germany.rds') %>%
#     mutate(year = as.integer(as.character(year))) %>%
#     filter(!is.na(value)) %>%
#     MySummary() %>%
#     mutate(Variable = 'Students in Germany') %>%
#     select(Variable, everything())
# 
# # su(mmary)
# su <- bind_rows(su.vars, su.ger) %>%
#     mutate(Interval = paste0(From, '--', To)) %>%
#     select(Variable, Interval, everything(), -From, -To)
# 
# i.stud <- su$Variable == 'Students'
# su$Interval[i.stud] <- paste0(su$Interval[i.stud], '\\tnote{2}')
# 
# su %>%
#     xtable(digits = 0) %>%
#     print(include.rownames       = FALSE,
#           floating               = FALSE,
#           booktabs               = TRUE,
#           sanitize.text.function = function(x) x,  # Leave backslashes alone
#           hline.after            = c(-1, 0, 4, nrow(.)),
#           file                   = fo.tab.desc)
# 
# # Total number of Goethe institutes covered by the dataset
# gl %>%
#     filter(!str_detect(city.de.harm.j, fixed('+'))) %>%
#     group_by(city.de.harm.j) %>%
#     summarise %>%
#     as.data.frame()


# Table: Descriptive statistics dependent and main independent variables
# -------------------------------------------------------------------------
fn.tab.desc.abrfree  <- 'tab-descriptives_abrfree.tex'  # Abroad Free Move
fn.tab.desc.abrrest  <- 'tab-descriptives_abrrest.tex'  # Abroad Restricted Move
fn.tab.desc.gerfree  <- 'tab-descriptives_gerfree.tex'  # Germany Free Move
fn.tab.desc.gerrest  <- 'tab-descriptives_gerrest.tex'  # Germany Restricted Move

fn.tab.desc.abrfreere  <- 'tab-descriptives_abrfreere.tex'  # Abroad Free Move RE
fn.tab.desc.abrrestre  <- 'tab-descriptives_abrrestre.tex'  # Abroad Restricted Move RE
fn.tab.desc.gerfreere  <- 'tab-descriptives_gerfreere.tex'  # Germany Free Move RE
fn.tab.desc.gerrestre  <- 'tab-descriptives_gerrestre.tex'  # Germany Restricted Move RE

vars <- c(
  'exams'            = 'Language Exams (abroad)',
  'students.inger'   = 'Language Students (in DE)',
  'mig.total'        = 'Immigration ($\\times 10^3$)',
  'mig.stock'        = 'Migrant Stock ($\\times 10^3$)',
  'students.fy'      = 'First-year Students ($\\times 10^3$)',
  'revenue'          = 'Trade Rev. with DE ($\\times 10^6$)',
  'gdp.pc'           = 'GDP per capita ($\\times 10^3$)',
  'pop'              = 'Population ($\\times 10^6$)',
  'pop.city'         = 'Population City ($\\times 10^6$)',
  'ling.dist'        = 'Linguistic Distance',
  'geo.dist'         = 'Geographic Distance ($\\times 10^2 \\mathit{km}$)',
  'ltowvs'           = 'Cultural Distance: LTO',
  'ivr'              = 'Cultural Distance: IVR',
  'german_speakers'  = 'Speakers of German (Perc.)',
  'total_speakers'   = 'World Speakers of Native Lang. ($\\times 10^6$)',
  'literacy.rate'    = 'Literacy Rate',
  'tertiary_enrol_gross' = 'Tertiary Education (Perc. Gross)',
  'political.rights' = 'Political Rights Index',
  'civil.liberties'  = 'Civil Liberties Index',
  'agriculture.share'= 'Agriculture Sector (Perc.)',
  'industry.share'   = 'Industry Sector (Perc.)',
  'services.share'   = 'Service Sector (Perc.)',
  'visa_required'    = 'Visa Required for Germany'
)

vars <- data.frame(variable = names(vars), Variable = vars)
rownames(vars) <- NULL

# CALCULATE STATISTICS
calculateStatistics <- . %>%
  group_by(variable) %>%
  summarise(#'Min.'      = min(value),
            #'Median'    = median(value),
            'Mean'      = mean(value),
            #'Max.'      = max(value),
            'Std Dev.'  = sd(value),
            '\\% Zeros' = sum(value == 0) / n() * 100)

adjustDimensions <- function(df, divisions) {
  for (var in names(divisions)) {
    if (var %in% names(df)) {
      df[[var]] <- df[[var]] / divisions[var]
    }
  }
  df
}
divisions <- c(mig.total        = 1000,
               mig.stock        = 1000,
               students.fy      = 1000,
               revenue          = 1000000,
               gdp.pc           = 1000,
               pop              = 1000000,
               pop.city         = 1000000,
               geo.dist         = 100,
               total_speakers   = 1000000)

source('prep_inger.R')

g.desc.free <- Fr1(g92) %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  #filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics

g.desc.rest <- Fr0(g92) %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  #filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics


g92Fr1 <- readRDS(file = "g92Fr1.rds")
g.desc.freere <- g92Fr1 %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics

g92Fr0 <- readRDS(file = "g92Fr0.rds")
g.desc.restre <- g92Fr0 %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics


source('prep_abr.R')
d$jr.case1[d$city=="Madrid"] <- FALSE # Do not exclude Madrid due to joint reporting (was jr.case=1)

FilterJr <- . %>%
  filter(!jr.case1) %>%
  filter(!jr.case2) %>%
  filter(!jr.case3) %>%
  filter(!jr.case4) %>%
  filter(!jr.case5)

Man <- . %>%
  FilterJr() %>%
  CenterLogs()


d.desc.free <- Man(Fr1(d)) %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  #filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics

d.desc.rest <- Man(Fr0(d)) %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  #filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics

dFr1 <- Man(readRDS(file = "dFr1.rds"))
d.desc.freere <- dFr1 %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics

dFr0 <- Man(readRDS(file = "dFr0.rds"))
d.desc.restre <- dFr0 %>%
  select_(.dots = c('year', 'country.iso3',
                    intersect(names(.), vars$variable))) %>%
  filter(complete.cases(.)) %>%
  adjustDimensions(divisions) %>%
  gather(variable, value, -year, -country.iso3) %>%
  calculateStatistics


# CREATE TABLES
createTable <- function(data, filename) {
  data %>%
    left_join(vars) %>%
    select(Variable, everything(), -variable) %>%
    mutate(Variable = factor(Variable, levels = vars$Variable)) %>%
    arrange(Variable) %>%
    xtable(digits = 2) %>%
    print(include.rownames       = FALSE,
          floating               = FALSE,
          booktabs               = TRUE,
          sanitize.text.function = function(x) x,  # Leave backslashes alone
          hline.after            = c(-1, 0, 1, nrow(.)),
          file                   = filename)
}

createTable(d.desc.free, fn.tab.desc.abrfree) # Abroad Free Move
createTable(d.desc.rest, fn.tab.desc.abrrest) # Abroad Restr. Move

createTable(g.desc.free, fn.tab.desc.gerfree) # Germany Free Move
createTable(g.desc.rest, fn.tab.desc.gerrest) # Germany Restr. Move

createTable(d.desc.freere, fn.tab.desc.abrfreere) # Abroad Free Move RE
createTable(d.desc.restre, fn.tab.desc.abrrestre) # Abroad Restr. Move RE

createTable(g.desc.freere, fn.tab.desc.gerfreere) # Germany Free Move RE
createTable(g.desc.restre, fn.tab.desc.gerrestre) # Germany Restr. Move RE

