#setwd()

source('00-libraries.R')

# Prep
source('prep_abr.R')
source('sets_of_variables.R')
source('estimation_helpers.R')


# Log-log specification according to Bell & Jones (2014, PSRM, eq. 12)
# -------------------------------------------------------------------------
# Do not exclude Madrid due to joint reporting (was jr.case=1)
d$jr.case1[d$city=="Madrid"] <- FALSE


BjD <- . %>%
  filter(!jr.case1) %>%
  filter(!jr.case2) %>%
  filter(!jr.case3) %>%
  filter(!jr.case4) %>%
  filter(!jr.case5) %>%
  CenterLogs() %>%
  group_by(city) %>%
  do(BjTransform(., DropInteractions(c(t.abr.main, t.fdi.eu)))) %>%
  ungroup()


# t.re is used as a default value by BjT(). Do not remove!
t.re <- c(
  '(1 | year)',
  '(1 | city)',
  '(1 | country.iso3)'
)

# Estimation defaults. Do not remove!
default.nsim <- 10000
default.data <- BjD(d)

source('subsetting_functions.R')

e.bj <- list()

# Schengen OR EU
e.bj[['fr']]   <- MyExamLogRe(BjT(t.abr.main), data = BjD(Fr1(d)))

# Schengen OR EU
e.bj[['nfr']]  <- MyExamLogRe(BjT(t.abr.main), data = BjD(Fr0(d)))


MyScreenReg(e.bj, as.list(vl.bea.wb))

saveEst(e.bj, 'tmp_output/est-abr_log_bj_NAME.rds')
