#setwd()

source('00-libraries.R')

# Prep
source('prep_inger.R')
source('estimation_helpers.R')
source('sets_of_variables.R')

# Log-log specification according to Bell & Jones (2014, PSRM, eq. 12)
# ------------------------------------------------------------------------------
BjD <- .  %>%
  CenterLogs() %>%
  group_by(country.iso3) %>%
  do(BjTransform(., DropInteractions(c(t.ger.main, t.fdi.eu)))) %>%
  ungroup()

# t.re is used as a default value by BjT(). Do not remove!
t.re <- c(
    '(1 | year)',
    '(1 | country.iso3)'
)

# Estimation defaults. Do not remove!
default.nsim <- 10000
default.data <- BjD(g92)

source('subsetting_functions.R')

e.bj <- list()

# Schenge OR EU
e.bj[['fr']]   <- MyGerLogRe(BjT(t.ger.main), data = BjD(Fr1(g92)))

# Schengen OR Eu
e.bj[['nfr']]  <- MyGerLogRe(BjT(t.ger.main), data = BjD(Fr0(g92)))


MyScreenReg(e.bj, as.list(vl.bea.wb))

library(ggplot2)
g92 %>%
  Eu1() %>%
  group_by(country.iso3) %>%
  summarise_each(funs(mean), population.l, trade.l) %>%
  ggplot(aes(x = population.l, y = trade.l)) +
    geom_point()

saveEst(e.bj, 'tmp_output/est-ger_log_bj_NAME.rds')
