#setwd()

source('00-libraries.R')

# Prep
source('prep_inger.R')
source('estimation_helpers.R')
source('sets_of_variables.R')

# Logged Specification
# -------------------------------------------------------------------------
# Estimation defaults. Do not remove!
default.data <- CenterLogs(g92)
source('subsetting_functions.R')

e <- list()
e[['main']]  <- MyGerLogFe(t.ger.main)
e[['eu']]    <- MyGerLogFe(t.ger.main, data = CenterLogs(Eu1(g92)))
e[['noneu']] <- MyGerLogFe(t.ger.main, data = CenterLogs(Eu0(g92)))

# Table 4: In Germany FE, Schengen or EU, stepwise
e[['fr1']]    <- MyGerLogFe(t.ger.1, data = CenterLogs(Fr1(g92)))
e[['fr2']]    <- MyGerLogFe(t.ger.2, data = CenterLogs(Fr1(g92)))
e[['fr']]    <- MyGerLogFe(t.ger.main, data = CenterLogs(Fr1(g92)))
e[['nonfr1']] <- MyGerLogFe(t.ger.1, data = CenterLogs(Fr0(g92)))
e[['nonfr2']] <- MyGerLogFe(t.ger.2, data = CenterLogs(Fr0(g92)))
e[['nonfr']] <- MyGerLogFe(t.ger.main, data = CenterLogs(Fr0(g92)))

# FDI instead of trade:
e[['fdi']]  <- MyGerLogFe(t.ger.main.fdi)

e[['highi99']] <- MyGerLogFe(t.ger.main, data = Hi99(g92))
e[['highi06']] <- MyGerLogFe(t.ger.main, data = Hi06(g92))
e[['lowi99']]  <- MyGerLogFe(t.ger.main, data = Li99(g92))
e[['lowi06']]  <- MyGerLogFe(t.ger.main, data = Li06(g92))

MyScreenReg(e, as.list(vl.bea))

saveEst(e, 'tmp_output/est-ger_log_fe_NAME.rds')


# Non-FE: In Germany Free and Restricted Move __________________________
g92Fr1 <- readRDS('g92Fr1.rds')
g92Fr0 <- readRDS('g92Fr0.rds')

e <- list()
e[['frRE']]    <- MyGerLogReNewFr1(t.ger.fr1, data = CenterLogs(g92Fr1))
e[['nonfrRE']] <- MyGerLogReNew(t.ger.fr0, data = CenterLogs(g92Fr0))

# FE: In germany Free and Restricted Move
e[['frFE']]    <- MyGerLogFe(t.ger.main, data = CenterLogs(g92Fr1))
e[['nonfrFE']] <- MyGerLogFe(t.ger.main, data = CenterLogs(g92Fr0))


MyScreenReg(e, as.list(vl.bea))

saveEst(e, 'tmp_output/est-ger_log_re_NAME.rds')


# IV-Approach ------------------------------------------------------------------
library(AER)

# Read in IV data
g92IV <- readRDS('g92IV.rds')

# First stage (EU and Schengen)
e <- list()
e[['fr1s']]       <- MyGerLogFeInsttest(t.iv.ger.inst.fr,    data = Fr1(g92IV))
e[['nonfr1s']]    <- MyGerLogFeInsttest(t.iv.ger.inst.nonfr, data = Fr0(g92IV))

# Second stage (EU and Schengen)
e[['fr2s']]       <- MyGerLogIV(t.iv.ger.ind, instr = t.iv.ger.inst.fr,    data = Fr1(g92IV))
e[['nonfr2s']]    <- MyGerLogIV(t.iv.ger.ind, instr = t.iv.ger.inst.nonfr, data = Fr0(g92IV))

e[['frFE']]       <- MyGerLogFe(t.iv.ger.ind, data = Fr1(g92IV))
e[['nonfrFE']]    <- MyGerLogFe(t.iv.ger.ind, data = Fr0(g92IV))

MyScreenReg(e, as.list(vl.bea))

saveEst(e, 'tmp_output/est-ger_log_IV_NAME.rds')

# Test for Instrument Validity
# Free Move
fr1s          <- MyGerLogFeInsttest(t.iv.ger.inst.fr, data = Fr1(g92IV))$est
fr1sresiduals <- fr1s$residuals
fr1sres       <- MyGerLogFeInsttest(t.iv.ger.instres, data = Fr1(g92IV))$est

instrFtestfr <- waldtest(fr1s, fr1sres)
print(instrFtestfr)
# we can clearly reject the null hypothesis that the instruments are irrelevant

# Restricted Move
nonfr1s          <- MyGerLogFeInsttest(t.iv.ger.inst.nonfr, data = Fr0(g92IV))$est
nonfr1sresiduals <- nonfr1s$residuals
nonfr1sres       <- MyGerLogFeInsttest(t.iv.ger.instres,    data = Fr0(g92IV))$est

instrFtestnonfr <- waldtest(nonfr1s, nonfr1sres)
print(instrFtestnonfr)
# we can clearly reject the null hypothesis that the instruments are irrelevant
# ______________________________________________________________________________

# Table 7: Robustness check: high and low income countries, Schengen and non-Schengen
e[['hifr']]   <- MyGerLogFe(t.ger.main, data = Fr1(Hi06(g92)))
e[['hinfr']]  <- MyGerLogFe(t.ger.main, data = Fr0(Hi06(g92)))
e[['lifr']]   <- MyGerLogFe(t.ger.main, data = Fr1(Li06(g92)))
e[['linfr']]  <- MyGerLogFe(t.ger.main, data = Fr0(Li06(g92)))

MyScreenReg(e, as.list(vl.bea))

saveEst(e, 'tmp_output/est-ger_inc_NAME.rds')

g92 %>%
  #Li06() %>%
  #Fr0() %>%
  select(country.iso3, year) %>%
  summarise_all(funs(length(unique(.))))

# ______________________________________________________________________________

# Diagnostic plots
pdf('fig-inger-log-main-sens.pdf', width=5, height=5)
par(mfrow = c(2, 2), mar = c(3, 2, 1.5, 1))
plot(e[['noneu']]$est)
dev.off()

# Sensitivity analysis
s <- MyEntitySensitivity(t.ger.main,
                         data = Eu0(g92),
                         MyGerLogFe,
                         'country.iso3',
                         'country.iso3|year')


# Estimation dataset staticics
g92 %>%
  Li06() %>%
  Fr0() %>%
  summarise(n = n(),
            num.countries = length(unique(country.iso3)),
            num.year      = length(unique(year)))

