#setwd

source('00-libraries.R')

source('estimation_helpers.R')
source('sets_of_variables.R')
source('prep_helpers.R')

# Load data
# ------------------------------------------------------------------------------
d.all <- LoadICY('/goethe/digitized/goethe-abroad.rds',
                 c('exams',
                   'jr.case1',
                   'jr.case2',
                   'jr.case3',
                   'jr.case4',
                   'jr.case5')) %>%
  filter(year %in% 1992:2006) %>%
  filter(!is.na(exams)) %>%
  # There are a no zeros in the exams variable.
  walk(print(sum(.$exams == 0))) %>%
  mutate(exams.l = log(exams))

d.all <- d.all %>%
  left_join(LoadIY('/population_cities/pop_city.rds', 'pop.city'),
            by = c('year', 'city')) %>%
  mutate(pop.city   = pop.city * 1000,
         pop.city.l = log(pop.city))

d.all <- d.all %>%
  left_join(LoadI('/capitals/capitals_wide.rds'))

d.all <- d.all %>%
  left_join(readRDS('controls-cy.rds'))

# Factorize year for regressions
d.all <- d.all %>%
  mutate(year = as.factor(year))

# Subsets
# -------------------------------------------------------------------------
d <- d.all %>%
  filter(country.iso3 != 'GRC') %>%
  filter(exams >= 5) %>%
  filter(complete.cases(.[, DropInteractions(t.abr.main)]))

# Create subset-dependent variables
# -------------------------------------------------------------------------
AddBiggestCityDummy <- function(df) {
  biggest.df <- df %>%
    group_by(country.iso3, city) %>%
    summarise(pop.mean = mean(pop.city, na.rm = TRUE)) %>%
    group_by(country.iso3) %>%
    arrange(pop.mean) %>%
    summarise(city     = last(city),
              pop.mean = last(pop.mean))
  df %>%
    mutate(is.biggest.city = city %in% biggest.df$city)
}

d <- d %>%
  AddBiggestCityDummy()

# Statistics
# ------------------------------------------------------------------------------
if (FALSE) {

# Report NAs by variable
d %>%
  summarise_each(funs(sum(is.na(.)))) %>%
  gather(variable, nas, everything()) %>%
  arrange(desc(nas))  
}

# Load Data for non-FE-Estimations
# ------------------------------------------------------------------------------
# Continent dummies
continent <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                            "Goethe_Macro", "Severin Daten", "data", "1_prepped", "continent", "continent.rds")))

# Cepii Distance measures 
distance_cepii <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                            "Goethe_Macro", "Severin Daten", "data", "1_prepped", "distance_measures_cepii", "distance_cepii.rds")))

# German speakers by country (Ginsburg paper)
german_speakers <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                             "Goethe_Macro", "Severin Daten", "data", "1_prepped", "spoken_language_ger", "german_speakers.rds")))

# Cultural distance (Hofstede 2010)
cultdist <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                      "Goethe_Macro", "Severin Daten", "data", "1_prepped", "cultural_distance", "cultdist.rds")))

cultdist$ltodist.norm <- (cultdist$ltodist/max(cultdist$ltodist, na.rm = TRUE)) # Long term orientation
cultdist$ivrdist.norm <- (cultdist$ivrdist/max(cultdist$ivrdist, na.rm = TRUE)) # Long term orientation

# Enrollment in tertiary public and private institutions (Worldbank)
tertiary_enrol_gross <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                            "Goethe_Macro", "Severin Daten", "data", "1_prepped", "tertiary_students", "tertiary_enrol_gross.rds")))

# Visa requirement
visa <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                  "Goethe_Macro", "Severin Daten", "data", "1_prepped", "visa_requirement", "visa.rds")))

# Literacy rate (2018 or most recent year)
literacy_rate <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                           "Goethe_Macro", "Severin Daten", "data", "1_prepped", "literacy_rate", "literacy_rate.rds")))

# World speakers of home country (spoken language, in case of multiple language max; 2020)
world_speakers <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                           "Goethe_Macro", "Severin Daten", "data", "1_prepped", "world_speakers", "world_speakers.rds")))
# Sectors
sectors <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                            "Goethe_Macro", "Severin Daten", "data", "1_prepped", "sectors", "sectors.rds")))

# FHI
fhi <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                     "Goethe_Macro", "Severin Daten", "data", "1_prepped", "fhi", "fhi.rds")))

# Distance measures (normalized)
d$geo.dist.norm  <- (d$geo.dist/max(d$geo.dist, na.rm = TRUE)) # geographic distance between capitals
d$ling.dist.norm <- (d$ling.dist/max(d$ling.dist, na.rm = TRUE)) # linguistic distance (Melitz Toubal)

default.data <- CenterLogs(d)
source('subsetting_functions.R')
dFr1 <- Fr1(d)
dFr1 <- merge(dFr1, cultdist)       # no losses
dFr1 <- merge(dFr1, distance_cepii) # no losses
dFr1 <- merge(dFr1, world_speakers) # no losses
dFr1 <- merge(dFr1, sectors)        # no losses
dFr1 <- merge(dFr1, tertiary_enrol_gross) # no losses
dFr1 <- merge(dFr1, german_speakers)# no losses
dFr1 <- merge(dFr1, continent)      # no losses
dFr1 <- merge(dFr1, fhi)            # no losses
dFr1 <- merge(dFr1, visa)           # no losses

dFr1$tertiary_enrol_gross.l <- log(dFr1$tertiary_enrol_gross)

dFr1$total_speakers.l  <- (log(dFr1$total_speakers))

# Filter complete cases for non-FE-Regression
dFr1 <- dFr1 %>% filter(complete.cases(country.iso3,
                                       year,
                                       exams.l,
                                       trade.l,
                                       tertiary_enrol_gross.l,
                                       geo.dist.norm,
                                       ling.dist.norm,
                                       ltodist.norm,
                                       ivrdist.norm,
                                       mig.total.l,
                                       mig.stock.l,
                                       students.fy.l,
                                       gdp.pc.l,
                                       population.l,
                                       pop.city.l,
                                       german_speakers,
                                       agriculture.share,
                                       industry.share,
                                       services.share,
                                       total_speakers.l
))

### Do not exclude Madrid due to joint reporting (was jr.case=1)
dFr1$jr.case1[dFr1$city=="Madrid"] <- FALSE

saveRDS(dFr1, file = "dFr1.rds")

# Restricted Move Estimation
dFr0 <- Fr0(d)
dFr0 <- merge(dFr0, continent, by = 'country.iso3')      # no losses
dFr0 <- merge(dFr0, tertiary_enrol_gross)           # no losses
dFr0 <- merge(dFr0, visa)           # no losses
dFr0 <- merge(dFr0, literacy_rate)  # no losses
dFr0 <- merge(dFr0, world_speakers) # no losses
dFr0 <- merge(dFr0, fhi)            # no losses
dFr0 <- merge(dFr0, german_speakers)# 14 losses
dFr0 <- merge(dFr0, sectors)        # 25 losses

dFr0$total_speakers.l       <- (log(dFr0$total_speakers))
dFr0$tertiary_enrol_gross.l <- log(dFr0$tertiary_enrol_gross)

# Filter complete cases for non-FE-Regression
dFr0 <- dFr0 %>% filter(complete.cases(country.iso3,
                                       year,
                                       exams.l,
                                       trade.l,
                                       tertiary_enrol_gross.l,
                                       geo.dist.norm,
                                       ling.dist.norm,
                                       mig.total.l,
                                       mig.stock.l,
                                       students.fy.l,
                                       gdp.pc.l,
                                       population.l,
                                       pop.city.l,
                                       literacy.rate,
                                       german_speakers,
                                       agriculture.share,
                                       industry.share,
                                       services.share,
                                       total_speakers.l
))

### Do not exclude Madrid due to joint reporting (was jr.case=1)
dFr0$jr.case1[dFr0$city=="Madrid"] <- FALSE

saveRDS(dFr0, file = "dFr0.rds")


# IV Data ----------------------------------------------------------------------
# Merge sectors and visa requirement to data
d$geo.dist.l <- log(d$geo.dist)

dIV <- merge(d, sectors)
dIV <- merge(dIV, visa)
dIV <- merge(dIV, fhi)
dIV <- merge(dIV, tertiary_enrol_gross)
dIV$services.l             <- log(dIV$services)
dIV$industry.l             <- log(dIV$industry)
dIV$agriculture.l          <- log(dIV$agriculture)
dIV$tertiary_enrol_gross.l <- log(dIV$tertiary_enrol_gross)
dIV$tertiary_enrol.norm    <-(dIV$tertiary_enrol_gross/max(dIV$tertiary_enrol_gross))

# Filter complete cases
dIV <- dIV %>% filter(complete.cases(country.iso3,
                                       year,
                                       exams.l,
                                       trade.l,
                                       mig.total.l,
                                       mig.stock.l,
                                       students.fy.l,
                                       gdp.pc.l,
                                       population.l,
                                       pop.city.l,
                                       agriculture.share,
                                       industry.share,
                                       services.share,
                                       geo.dist.l,
                                       tertiary_enrol_gross.l
))

### Do not exclude Madrid due to joint reporting (was jr.case=1)
dIV$jr.case1[dIV$city=="Madrid"] <- FALSE

saveRDS(dIV, file = "dIV.rds")
