FnPrepped <- function(fn.rel, variables) {
  paste0(
    file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
              "Goethe_Macro", "Severin Daten", "data", "1_prepped"), fn.rel)
}

list('country.iso3'   = as.character,
     'year'           = function(x)  as.integer(as.character(x)),
     'city.de.harm.j' = as.character)

LoadPrepped <- function(fn.rel, variables, identifiers) {

  # 1. Read data
  df <- FnPrepped(fn.rel) %>%
    readRDS() %>%
    tbl_df()

  # 2. Modify identifiers (e.g. set column types)
  for (var in names(identifiers)) {
    df[[var]] <- identifiers[[var]](df[[var]])
  }

  # 3. Spread if necessary
  # Most of the data are prepped in ultra-long format, the colums are:
  # identifiers, variable, value, but we want to go ahead with standard long
  # format, where each column represents a variable
  if ('variable' %in% names(df)) {
    df <- spread(df, variable, value, convert = TRUE)
  }

  # 4. Drop unwanted variables
  if (!missing(variables)) {
    if (!all(variables %in% names(df))) {
      stop('You requested a variable that is not in the dataset.')
    }

    df <- df %>%
      select_(.dots = c(names(identifiers), variables))
  }

  df
}

LoadICY <- function(fn.rel, variables) {
  LoadPrepped(fn.rel, variables, list(
    'country.iso3' = as.character,
    'year'         = function(x)  as.integer(as.character(x)),
    'city'         = as.character
  ))
}
LoadCY <- function(fn.rel, variables) {
  LoadPrepped(fn.rel, variables, list(
    'country.iso3'   = as.character,
    'year'           = function(x)  as.integer(as.character(x))
  ))
}
LoadIC <- function(fn.rel, variables) {
  LoadPrepped(fn.rel, variables, list(
    'country.iso3'   = as.character,
    'city'           = as.character
  ))
}
LoadIY <- function(fn.rel, variables) {
  LoadPrepped(fn.rel, variables, list(
    'city'           = as.character,
    'year'           = function(x)  as.integer(as.character(x))
  ))
}
LoadI <- function(fn.rel, variables) {
  LoadPrepped(fn.rel, variables, list(
    'city'           = as.character
  ))
}
LoadC <- function(fn.rel, variables) {
  LoadPrepped(fn.rel, variables, list(
    'country.iso3' = as.character
  ))
}

ReplaceVal <- function(x, val, replacement)  replace(x, x %in% val, replacement)
ReplaceNa  <- function(x, replacement)       replace(x, is.na(x), replacement)
ReplaceNeg <- function(x, replacement)       replace(x, x < 0,    replacement)
