#setwd

source('00-libraries.R')

source('estimation_helpers.R')
source('sets_of_variables.R')
source('prep_helpers.R')

g.all <- LoadCY('/goethe/digitized_in_Germany/goethe_in_Germany.rds') %>%
  filter(year %in% 1992:2006) %>%
  filter(!is.na(students.inger)) %>%
  # We have to decide how to treat zeros in the log-log specification.
  # Robustness check have to be conducted on this decision.
  mutate(students.inger.l = log(ReplaceVal(students.inger, 0, 0.5))) %>%
  left_join(readRDS('controls-cy.rds'))

# Factorize year for regressions
g.all <- g.all %>%
  mutate(year = as.factor(year))

# Drop incomplete cases
g92 <- g.all %>%
  filter(complete.cases(.[, DropInteractions(t.ger.main)]))

# Statistics
# -------------------------------------------------------------------------
if (FALSE) {

# Report NAs by variable
g.all %>%
  summarise_each(funs(sum(is.na(.)))) %>%
  gather(variable, nas, everything())
  
}

# Create Data for RE-Estimations
# ------------------------------------------------------------------------------
# Continent dummies
continent <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                       "Goethe_Macro", "Severin Daten", "data", "1_prepped", "continent", "continent.rds")))

# Cepii Distance measures 
distance_cepii <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                            "Goethe_Macro", "Severin Daten", "data", "1_prepped", "distance_measures_cepii", "distance_cepii.rds")))

# German speakers by country (Ginsburg paper)
german_speakers <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                             "Goethe_Macro", "Severin Daten", "data", "1_prepped", "spoken_language_ger", "german_speakers.rds")))


# Cultural distance (Hofstede 2010)
cultdist <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                      "Goethe_Macro", "Severin Daten", "data", "1_prepped", "cultural_distance", "cultdist.rds")))

cultdist$ltodist.norm <- (cultdist$ltodist/max(cultdist$ltodist, na.rm = TRUE)) # Long term orientation
cultdist$ivrdist.norm <- (cultdist$ivrdist/max(cultdist$ivrdist, na.rm = TRUE)) # Long term orientation

# Enrollment in tertiary public and private institutions (Worldbank)
tertiary_enrol_gross <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                            "Goethe_Macro", "Severin Daten", "data", "1_prepped", "tertiary_students", "tertiary_enrol_gross.rds")))
# Visa requirement
visa <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                  "Goethe_Macro", "Severin Daten", "data", "1_prepped", "visa_requirement", "visa.rds")))

# Literacy rate (2018 or most recent year)
literacy_rate <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                           "Goethe_Macro", "Severin Daten", "data", "1_prepped", "literacy_rate", "literacy_rate.rds")))

# World speakers of home country (spoken language, in case of multiple language max; 2020)
world_speakers <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                            "Goethe_Macro", "Severin Daten", "data", "1_prepped", "world_speakers", "world_speakers.rds")))

# Sectors
sectors <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                     "Goethe_Macro", "Severin Daten", "data", "1_prepped", "sectors", "sectors.rds")))

# FHI
fhi <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                     "Goethe_Macro", "Severin Daten", "data", "1_prepped", "fhi", "fhi.rds")))


# Distance measures (normalized)
g92$geo.dist.norm  <- (g92$geo.dist/max(g92$geo.dist, na.rm = TRUE)) # geographic distance between capitals
g92$ling.dist.norm <- (g92$ling.dist/max(g92$ling.dist, na.rm = TRUE)) # linguistic distance (Melitz Toubal)

# non-FE Estimation-------------------------------------------------------------
# Free Move Estimation
default.data <- CenterLogs(g92)
source('subsetting_functions.R')

g92Fr1 <- Fr1(g92)
g92Fr1 <- merge(g92Fr1, fhi)             # no losses
g92Fr1 <- merge(g92Fr1, world_speakers)  # no losses
g92Fr1 <- merge(g92Fr1, sectors)         # no losses
g92Fr1 <- merge(g92Fr1, german_speakers) # no losses
g92Fr1 <- merge(g92Fr1, distance_cepii)  # no losses
g92Fr1 <- merge(g92Fr1, continent)       # no losses
g92Fr1 <- merge(g92Fr1, tertiary_enrol_gross)  # loss of 3 observations
g92Fr1 <- merge(g92Fr1, cultdist)        # loss of 3 observations
g92Fr1 <- merge(g92Fr1, visa)            # no losses

g92Fr1$total_speakers.l  <- (log(g92Fr1$total_speakers))
g92Fr1$tertiary_enrol_gross.l <- log(g92Fr1$tertiary_enrol_gross)

# Filter complete cases for RE-Regression
g92Fr1 <- g92Fr1 %>% filter(complete.cases(country.iso3,
                                           year,
                                           students.inger.l,
                                           trade.l,
                                           tertiary_enrol_gross.l,
                                           geo.dist.norm,
                                           ling.dist.norm,
                                           ltodist.norm,
                                           ivrdist.norm,
                                           mig.total.l,
                                           mig.stock.l,
                                           students.fy.l,
                                           gdp.pc.l,
                                           population.l,
                                           german_speakers,
                                           agriculture.share,
                                           industry.share,
                                           services.share,
                                           total_speakers.l,
                                           political.rights,
                                           civil.liberties
))

saveRDS(g92Fr1, file = "g92Fr1.rds")

# Restricted Move Estimation
g92Fr0 <- Fr0(g92)
g92Fr0 <- merge(g92Fr0, tertiary_enrol_gross) # 648 losses
g92Fr0 <- merge(g92Fr0, visa)           # no losses
g92Fr0 <- merge(g92Fr0, literacy_rate)  # no losses
g92Fr0 <- merge(g92Fr0, fhi)            # 15 losses
g92Fr0 <- merge(g92Fr0, world_speakers) # 54 losses
g92Fr0 <- merge(g92Fr0, german_speakers)# 135 losses
g92Fr0 <- merge(g92Fr0, sectors)        # 159 losses
g92Fr0 <- merge(g92Fr0, continent)      # no losses

g92Fr0$total_speakers.l  <- (log(g92Fr0$total_speakers))
g92Fr0$tertiary_enrol_gross.l <- log(g92Fr0$tertiary_enrol_gross)

# Filter complete cases for non-FE-Regression
g92Fr0 <- g92Fr0 %>% filter(complete.cases(country.iso3,
                                           year,
                                           students.inger.l,
                                           trade.l,
                                           tertiary_enrol_gross.l,
                                           geo.dist.norm,
                                           ling.dist.norm,
                                           mig.total.l,
                                           mig.stock.l,
                                           students.fy.l,
                                           gdp.pc.l,
                                           population.l,
                                           continent.code,
                                           literacy.rate,
                                           german_speakers,
                                           agriculture.share,
                                           industry.share,
                                           services.share,
                                           total_speakers.l,
                                           political.rights,
                                           civil.liberties
))

saveRDS(g92Fr0, file = "g92Fr0.rds")


# IV-Approach __________________________________________________________________
# Merge sectors and visa requirement to data
sectors <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                     "Goethe_Macro", "Severin Daten", "data", "1_prepped", "sectors", "sectors.rds")))

visa <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                  "Goethe_Macro", "Severin Daten", "data", "1_prepped", "visa_requirement", "visa.rds")))

# FHI
fhi <- na.omit(readRDS(file.path("C:", "Users", "Ann-Marie Sommerfeld", "OneDrive - benefitcfgau", "Uni", "Uni Goettingen", "Projekte", "Language and Migration",
                                 "Goethe_Macro", "Severin Daten", "data", "1_prepped", "fhi", "fhi.rds")))

g92$geo.dist.l <- log(g92$geo.dist)

g92IV <- merge(g92, sectors)
g92IV <- merge(g92IV, visa)
g92IV <- merge(g92IV, fhi)
g92IV <- merge(g92IV, tertiary_enrol_gross)
g92IV$services.l <- log(g92IV$services)
g92IV$industry.l <- log(g92IV$industry)
g92IV$agriculture.l <- log(g92IV$agriculture)
g92IV$tertiary_enrol_gross.l <- log(g92IV$tertiary_enrol_gross)

# Filter complete cases
g92IV <- g92IV %>% filter(complete.cases(country.iso3,
                                     students.inger.l,
                                     year,
                                     trade.l,
                                     mig.total.l,
                                     mig.stock.l,
                                     students.fy.l,
                                     gdp.pc.l,
                                     population.l,
                                     agriculture.share,
                                     industry.share,
                                     services.share,
                                     geo.dist.l,
                                     tertiary_enrol_gross.l
))

### Do not exclude Madrid due to joint reporting (was jr.case=1)
saveRDS(g92IV, file = "g92IV.rds")
