# Sets of variables used throughout all the estimations
# -------------------------------------------------------------------------
fe.y   <- c('year')
fe.yr  <- c('year', 'continent.code')
fe.yc  <- c('year', 'city')
fe.yco <- c('year', 'country.iso3')
fe.yci <- c('year', 'city', 'country.iso3')


# Sets of variables for estimation purposes
# -------------------------------------------------------------------------
# Both estimations
t.tra      <- c('trade.l')
t.fdi      <- c('fdi.inc.l', 'fdi.out.l')
t.tra.eu   <- c('trade.l*eu')
t.fdi.eu   <- c('fdi.inc.l*eu', 'fdi.out.l*eu')

t.dist.fr1 <- c(
              'geo.dist.norm',
              'ling.dist.norm',
              'ltodist.norm',
              'ivrdist.norm',
              'tertiary_enrol_gross.l',
              'total_speakers.l',
              'german_speakers',
              'agriculture.share',
              'industry.share',
              'services.share'
)

t.dist.fr0 <- c(
               'visa_required',
               'geo.dist.norm',
               'ling.dist.norm',
               'literacy.rate',
               'tertiary_enrol_gross.l',
               'total_speakers.l',
               'german_speakers',
               'agriculture.share',
               'industry.share',
               'services.share',
               'political.rights',
               'civil.liberties'
)

# Abroad estimation
t.abr.1 <- c('mig.total.l')

t.abr.2 <- c('mig.total.l',
             'mig.total.l*mig.stock.l',
             'students.fy.l',
             'students.fy.l*mig.stock.l',
             'mig.stock.l',
             'mig.total.l*gdp.pc.l'
)

t.abr.base <- c(
  'population.l',
  'pop.city.l',
  'mig.total.l',
  'mig.total.l*mig.stock.l',
  'students.fy.l',
  'students.fy.l*mig.stock.l',
  'mig.stock.l',
  'mig.total.l*gdp.pc.l'
)

t.abr.eu <- c(
  'population.l*eu',
  'pop.city.l*eu',
  'mig.total.l*eu',
  'mig.stock.l*eu',
  'mig.total.l*mig.stock.l',
  'students.fy.l*eu'
)
t.abr.con <- c(
  'gdp.pc.l'
)

# IV
t.iv.abr.ind <- c('mig.total.l',
                  'students.fy.l',
                  'mig.stock.l',
                  'trade.l',
                  'population.l',
                  'pop.city.l',
                  'gdp.pc.l')

t.iv.abr.inst.fr <- c('geo.dist.l:population.l',
                     'mig.stock.l',
                     'tertiary_enrol_gross:population.l',
                     'agriculture.l:population.l',
                     'students.fy.l',
                     'trade.l',
                     'population.l',
                     'pop.city.l',
                     'gdp.pc.l')

t.iv.abr.inst.nonfr <- c('geo.dist.l:population.l',
                         'mig.stock.l',
                         'tertiary_enrol_gross:population.l',
                         'agriculture.l:population.l',
                         'students.fy.l',
                         'trade.l',
                         'population.l',
                         'pop.city.l',
                         'gdp.pc.l')


t.iv.abr.instres <- c(
                   'mig.stock.l',
                   'students.fy.l',
                   'trade.l',
                   'population.l',
                   'pop.city.l',
                   'gdp.pc.l')


t.abr.2         <- c(t.abr.2)
t.abr.main      <- c(t.abr.base, t.tra, t.abr.con)
t.abr.main.fdi  <- c(t.abr.base, t.fdi, t.abr.con)
t.abr.fr1       <- c(t.abr.base, t.tra, t.abr.con, t.dist.fr1)
t.abr.fr0       <- c(t.abr.base, t.tra, t.abr.con, t.dist.fr0)

TAbrStud <- function(new.var = NULL) {
  c(t.abr.main[!(t.abr.main == 'students.fy.l')], new.var)
}

# In-Germany estimation
t.ger.1 <- c(
  'mig.total.l'
)

t.ger.2 <- c(
  'mig.total.l',
  'mig.total.l*mig.stock.l',
  'students.fy.l',
  'students.fy.l*mig.stock.l',
  'mig.stock.l',
  'mig.total.l*gdp.pc.l'
)

t.ger.base <- c(
  'population.l',
  'mig.total.l',
  'mig.total.l*mig.stock.l',
  'students.fy.l',
  'students.fy.l*mig.stock.l',
  'mig.stock.l',
  'mig.total.l*gdp.pc.l'
)
t.ger.eu <- c(
  'population.l*eu',
  'mig.total.l*eu',
  'mig.stock.l*eu',
  'mig.total.l*mig.stock.l',
  'students.fy.l*eu'
)
t.ger.con <- c(
  'gdp.pc.l'
)

# IV
t.iv.ger.ind <- c('mig.total.l',
                  'students.fy.l',
                  'mig.stock.l',
                  'trade.l',
                  'population.l',
                  'gdp.pc.l')

t.iv.ger.inst.fr <- c('geo.dist.l:population.l',
                      'mig.stock.l',
                      'students.fy.l',
                      'agriculture.l:population.l',
                      'tertiary_enrol_gross:population.l',
                      'trade.l',
                      'population.l',
                      'gdp.pc.l')

t.iv.ger.inst.nonfr <- c('geo.dist.l:population.l',
                         'mig.stock.l',
                         'agriculture.l:population.l',
                         'tertiary_enrol_gross:population.l',
                         'students.fy.l',
                         'trade.l',
                         'population.l',
                         'gdp.pc.l')


t.iv.ger.instres <- c('mig.stock.l',
                      'trade.l',
                      'population.l',
                      'gdp.pc.l')

t.ger.2        <- c(t.ger.2)
t.ger.main     <- c(t.ger.base, t.tra, t.ger.con)
t.ger.main.fdi <- c(t.ger.base, t.fdi, t.ger.con)
t.ger.fr0      <- c(t.ger.base, t.tra, t.ger.con, t.dist.fr0)
t.ger.fr1      <- c(t.ger.base, t.tra, t.ger.con, t.dist.fr1)

TGerStud <- function(new.var = NULL) {
  c(t.ger.main[!(t.ger.main == 'students.fy.l')], new.var)
}

# Ordered lists of variables
# -------------------------------------------------------------------------
vl.bea <- c(
  # Migration Flows (t)
  'mig.total.l'                         = 'Immigration',
  'mig.total.l:eu'                      = 'Imm. XX EU',
  'mig.total.l:gdp.pc.l'                = 'Imm. XX GDP per capita',
  'mig.total.l:gdp.pc.dev'              = 'Imm. XX Dev. from GDP Trend',
  'mig.total.l:gdp.pc.dev:eu'           = 'Imm. XX Dev. from GDP Trend XX EU',
  'mig.total.l:ling.dist'               = 'Imm. XX Ling. Dist.',
  'mig.total.l:ling.dist.cat---'        = 'Imm. XX Ling. Dist. (---)',
  'mig.total.l:ling.dist.cat--'         = 'Imm. XX Ling. Dist. (--)',
  'mig.total.l:ling.dist.cat-'          = 'Imm. XX Ling. Dist. (-)',
  'mig.total.l:ling.dist.cat+'          = 'Imm. XX Ling. Dist. (+)',
  'mig.total.l:ling.dist.cat++'         = 'Imm. XX Ling. Dist. (++)',
  'mig.total.l:ling.dist.cat+++'        = 'Imm. XX Ling. Dist. (+++)',
  'mig.total.l:geo.dist.w'              = 'Imm. XX Geo. Dist.',
  'mig.total.l:geo.dist.w:eu'           = 'Imm. XX Geo. Dist. XX EU',
  'mig.total.l:geo.dist.w.l'            = 'Imm. XX Geo. Dist.',
  'mig.total.l:geo.dist.w.l:eu'         = 'Imm. XX Geo. Dist. XX EU',
  # Migration Flows (t+1)
  'mig.total.f1.l'                      = 'Immigration',
  'mig.total.f1.l:eu'                   = 'Imm. XX EU',
  'mig.total.f1.l:gdp.pc.dev'           = 'Imm. XX Dev. from GDP Trend',
  'mig.total.f1.l:gdp.pc.dev:eu'        = 'Imm. XX Dev. from GDP Trend XX EU',
  'mig.total.f1.l:ling.dist'            = 'Imm. XX Ling. Dist.',
  'mig.total.f1.l:ling.dist.cat---'     = 'Imm. XX Ling. Dist. (---)',
  'mig.total.f1.l:ling.dist.cat--'      = 'Imm. XX Ling. Dist. (--)',
  'mig.total.f1.l:ling.dist.cat-'       = 'Imm. XX Ling. Dist. (-)',
  'mig.total.f1.l:ling.dist.cat+'       = 'Imm. XX Ling. Dist. (+)',
  'mig.total.f1.l:ling.dist.cat++'      = 'Imm. XX Ling. Dist. (++)',
  'mig.total.f1.l:ling.dist.cat+++'     = 'Imm. XX Ling. Dist. (+++)',
  'mig.total.f1.l:geo.dist.w'           = 'Imm. XX Geo. Dist.',
  'mig.total.f1.l:geo.dist.w:eu'        = 'Imm. XX Geo. Dist. XX EU',
  'mig.total.f1.l:geo.dist.w.l'         = 'Imm. XX Geo. Dist.',
  'mig.total.f1.l:geo.dist.w.l:eu'      = 'Imm. XX Geo. Dist. XX EU',
  # Migration Flows (others)
  'mig.total.f2.l'                      = 'Immigration',
  'mig.total.f12.l'                     = 'Immigration',
  'mig.total.f012.l'                    = 'Immigration',
  'mig.total.f01.l'                     = 'Immigration',
  'mig.total.l1.l'                      = 'Immigration',
  'mig.total.l01.l'                     = 'Immigration',
  # Student Stocks
  'foreign.students.l3.l'               = 'Student Mig. Stock $(t-3)$',
  'foreign.students.l2.l'               = 'Student Mig. Stock $(t-2)$',
  'foreign.students.l1.l'               = 'Student Mig. Stock $(t-1)$',
  'foreign.students.l'                  = 'Student Mig. Stock',
  'foreign.students.l:eu'               = 'SMS XX EU',
  'foreign.students.f1.l'               = 'Student Mig. Stock $(t+1)$',
  'foreign.students.f2.l'               = 'Student Mig. Stock $(t+2)$',
  'foreign.students.f3.l'               = 'Student Mig. Stock $(t+3)$',
  'foreign.students.f1.l:eu'            = 'SMS XX EU',
  'foreign.students.l:gdp.pc.dev'       = 'SMS XX Dev. from GDP Trend',
  'foreign.students.l:gdp.pc.dev:eu'    = 'SMS XX Dev. from GDP Trend XX EU',
  'foreign.students.l:ling.dist'        = 'SMS XX Ling. Dist.',
  'foreign.students.l:ling.dist.cat---' = 'SMS XX Ling. Dist. (---)',
  'foreign.students.l:ling.dist.cat--'  = 'SMS XX Ling. Dist. (--)',
  'foreign.students.l:ling.dist.cat-'   = 'SMS XX Ling. Dist. (-)',
  'foreign.students.l:ling.dist.cat+'   = 'SMS XX Ling. Dist. (+)',
  'foreign.students.l:ling.dist.cat++'  = 'SMS XX Ling. Dist. (++)',
  'foreign.students.l:ling.dist.cat+++' = 'SMS XX Ling. Dist. (+++)',
  'foreign.students.l:geo.dist.w'       = 'SMS XX Geo. Dist.',
  'foreign.students.l:geo.dist.w:eu'    = 'SMS XX Geo. Dist. XX EU',
  'foreign.students.l:geo.dist.w.l'     = 'SMS XX Geo. Dist.',
  'foreign.students.l:geo.dist.w.l:eu'  = 'SMS XX Geo. Dist. XX EU',
  # Students Inflows (First-year students)
  'students.fy.l3.l'                    = 'Foreign First-year Students $(t-3)$',
  'students.fy.l2.l'                    = 'Foreign First-year Students $(t-2)$',
  'students.fy.l1.l'                    = 'Foreign First-year Students $(t-1)$',
  'students.fy.l'                       = 'Student Imm.',
  'students.fy.f1.l'                    = 'Foreign First-year Students $(t+1)$',
  'students.fy.f2.l'                    = 'Foreign First-year Students $(t+2)$',
  'students.fy.f3.l'                    = 'Foreign First-year Students $(t+3)$',
  'students.fy.l:eu'                    = 'FFS XX EU',
  'students.fy.f1.l:eu'                 = 'FFS XX EU',
  'students.fy.l:mig.stock.l'           = 'Student Imm. XX Mig. Stock',
  # Students Inflows (First-year BildungsauslC$nder students)
  'ba.firstyear.i.l'                    = 'Foreign-educated First-year Students',
  # Migrant Stocks
  'mig.stock.l'                         = 'Migrant Stocks',
  'mig.stock.l:eu'                      = 'MS XX EU',
  'mig.stock.l:gdp.pc.dev'              = 'MS XX Dev. from GDP Trend',
  'mig.stock.l:gdp.pc.dev:eu'           = 'MS XX Dev. from GDP Trend XX EU',
  'mig.stock.l:ling.dist'               = 'MS XX Ling. Dist.',
  'mig.stock.l:ling.dist.cat---'        = 'MS XX Ling. Dist. (---)',
  'mig.stock.l:ling.dist.cat--'         = 'MS XX Ling. Dist. (--)',
  'mig.stock.l:ling.dist.cat-'          = 'MS XX Ling. Dist. (-)',
  'mig.stock.l:ling.dist.cat+'          = 'MS XX Ling. Dist. (+)',
  'mig.stock.l:ling.dist.cat++'         = 'MS XX Ling. Dist. (++)',
  'mig.stock.l:ling.dist.cat+++'        = 'MS XX Ling. Dist. (+++)',
  'mig.stock.l:geo.dist.w'              = 'MS XX Geo. Dist.',
  'mig.stock.l:geo.dist.w:eu'           = 'MS XX Geo. Dist. XX EU',
  'mig.stock.l:geo.dist.w.l'            = 'MS XX Geo. Dist.',
  'mig.stock.l:geo.dist.w.l:eu'         = 'MS XX Geo. Dist. XX EU',
  # Stock X Flow
  'mig.total.l:mig.stock.l'             = 'Imm. XX Mig. Stock',
  'mig.total.f1.l:mig.stock.l'          = 'Imm. XX Mig. Stock',
  'mig.total.f2.l:mig.stock.l'          = 'Imm. XX Mig. Stock',
  'mig.total.f12.l:mig.stock.l'         = 'Imm. XX Mig. Stock',
  'mig.total.f012.l:mig.stock.l'        = 'Imm. XX Mig. Stock',
  'mig.total.f01.l:mig.stock.l'         = 'Imm. XX Mig. Stock',
  'mig.total.l1.l:mig.stock.l'          = 'Imm. XX Mig. Stock',
  'mig.total.l01.l:mig.stock.l'         = 'Imm. XX Mig. Stock',
  # Trade
  'revenue.share.e2.l'                  = 'Trade',
  'revenue.share.e2.l:eu'               = 'Trade XX EU',
  'revenue.share.e2.l:gdp.pc.dev'       = 'Trade XX Dev. from GDP Trend',
  'revenue.share.e2.l:gdp.pc.dev:eu'    = 'Trade XX Dev. from GDP Trend XX EU',
  'revenue.share.e2.l:ling.dist'        = 'Trade XX Ling. Dist.',
  'revenue.share.e2.l:ling.dist.cat---' = 'Trade XX Ling. Dist. (---)',
  'revenue.share.e2.l:ling.dist.cat--'  = 'Trade XX Ling. Dist. (--)',
  'revenue.share.e2.l:ling.dist.cat-'   = 'Trade XX Ling. Dist. (-)',
  'revenue.share.e2.l:ling.dist.cat+'   = 'Trade XX Ling. Dist. (+)',
  'revenue.share.e2.l:ling.dist.cat++'  = 'Trade XX Ling. Dist. (++)',
  'revenue.share.e2.l:ling.dist.cat+++' = 'Trade XX Ling. Dist. (+++)',
  'revenue.share.e2.l:geo.dist.w'       = 'Trade XX Geo. Dist.',
  'revenue.share.e2.l:geo.dist.w:eu'    = 'Trade XX Geo. Dist. XX EU',
  'revenue.share.e2.l:geo.dist.w.l'     = 'Trade XX Geo. Dist.',
  'revenue.share.e2.l:geo.dist.w.l:eu'  = 'Trade XX Geo. Dist. XX EU',
  'trade.l'                             = 'Trade',
  'trade.l:eu'                          = 'Trade XX EU',
  'trade.l:gdp.pc.dev'                  = 'Trade XX Dev. from GDP Trend',
  'trade.l:gdp.pc.dev:eu'               = 'Trade XX Dev. from GDP Trend XX EU',
  'trade.l:ling.dist'                   = 'Trade XX Ling. Dist.',
  'trade.l:ling.dist.cat---'            = 'Trade XX Ling. Dist. (---)',
  'trade.l:ling.dist.cat--'             = 'Trade XX Ling. Dist. (--)',
  'trade.l:ling.dist.cat-'              = 'Trade XX Ling. Dist. (-)',
  'trade.l:ling.dist.cat+'              = 'Trade XX Ling. Dist. (+)',
  'trade.l:ling.dist.cat++'             = 'Trade XX Ling. Dist. (++)',
  'trade.l:ling.dist.cat+++'            = 'Trade XX Ling. Dist. (+++)',
  'trade.l:geo.dist.w'                  = 'Trade XX Geo. Dist.',
  'trade.l:geo.dist.w:eu'               = 'Trade XX Geo. Dist. XX EU',
  'trade.l:geo.dist.w.l'                = 'Trade XX Geo. Dist.',
  'trade.l:geo.dist.w.l:eu'             = 'Trade XX Geo. Dist. XX EU',
  'fdi.inc.l'                           = 'Incoming FDI',
  'fdi.inc.l:eu'                        = 'Incoming FDI XX EU',
  'fdi.out.l'                           = 'Outgoing FDI',
  'fdi.out.l:eu'                        = 'Outgoing FDI XX EU',
  # Others
  'eu'                                  = 'EU',
  'gdp.pc.l'                            = 'GDP per capita',
  'gdp.pc.dev'                          = 'Dev. from GDP Trend',
  'gdp.pc.dev:eu'                       = 'Dev. from GDP Trend XX EU',
  'population.l'                        = 'Population',
  'population.l:geo.dist.w'             = 'Pop. XX Geo. Dist.',
  'population.l:geo.dist.w:eu'          = 'Pop. XX Geo. Dist. XX EU',
  'population.l:geo.dist.w.l'           = 'Pop. XX Geo. Dist.',
  'population.l:geo.dist.w.l:eu'        = 'Pop. XX Geo. Dist. XX EU',
  'pop.city.l'                          = 'Population City',
  'ling.dist'                           = 'Linguistic Distance (BTW)',
  'ling.dist.cat-'                      = 'Linguistic Distance (-) (BTW)',
  'ling.dist.cat+'                      = 'Linguistic Distance (+) (BTW)',
  'ling.dist.norm'                      = 'Linguistic Distance to Germany',
  'geo.dist'                            = 'Geographic Distance (BTW)',
  'geo.dist.l'                          = 'Geographic Distance (Log)',
  'geo.dist.w'                          = 'Geographic Distance (BTW)',
  'geo.dist.norm'                       = 'Geographic Distance to Germany',
  'ltodist.norm'                        = 'Cultural Distance to Germany: LTO',
  'ivrdist.norm'                        = 'Cultural Distance to Germany: IVR',
  
  # Controls
  'shared_border'                       = 'Shared Border w/ Germany',
  'smctry'                              = 'Once Same Country as Germany',
  'colony'                              = 'Colonial link w/ Germany',
  'curcol'                              = 'Current Colonial Rel. w/ Germany',
  'col45'                               = 'Colonial Rel. w/ Germany after 1945',
  'comlang_off'                         = 'Shares Official Lang. w/ Germany',
  'comlang_ethno'                       = 'Shares Spoken Lang. w/ Germany',
  'german_speakers'                     = 'Speakers of German (Perc.)',
  'tertiary_enrol.pop.l'                = 'Tertiary Education (Perc.)',
  'tertiary_enrol_gross.l'              = 'Tertiary Enrolment (Perc. Gross)',
  'years_schooling2000'                 = 'Avg. years of schooling (2000)',
  'unemp_rate'                          = 'Unemployment Rate',
  'visa_required'                       = 'Visa Required for Germany',
  'literacy.rate'                       = 'Literacy Rate',
  'agriculture.share'                   = 'Agriculture Sector (Perc.)',
  'industry.share'                      = 'Industry Sector (Perc.)',
  'services.share'                      = 'Services Sector (Perc.)',
  'industry.l'                          = 'Industry Sector (Log)',
  'continent.code'                      = 'Continent FE',
  'total_speakers.l'                    = 'World Speakers of Native Lang.',
  'political.rights'                    = 'Political Rights Index',
  'civil.liberties'                     = 'Civil Liberties Index',
  # IV
  'geo.dist.l:trade.l'                  = 'Geographic Distance XX Trade',
  'geo.dist.l:population.l'             = 'Geo. Dist. XX Population',
  'geo.dist:population.l'               = 'Geo. Dist. XX Population',
  'geo.dist.norm:population.l'          = 'Geo. Dist. XX Population',
  'visa_required:population.l'          = 'Visa Required XX Population',
  'geo.dist.l:industry.share'           = 'Geographic Distance XX Industry Share',
  'geo.dist.l:industry.l'               = 'Geographic Distance XX Industry',
  'political.rights:population.l'       = 'Political Rights Index XX Population',
  'civil.liberties:population.l'        = 'Civil Liberties XX Population',
  'agriculture.share:population.l'      = 'Agriculture Sector (Perc.) XX Population',
  'industry.share:population.l'         = 'Industry Sector (Perc.) XX Population',
  'services.share:population.l'         = 'Services Sector (Perc.) XX Population',
  'agriculture.l:population.l'          = 'Agriculture Sector XX Population',
  'industry.l:population.l'             = 'Industry Sector XX Population',
  'services.l:population.l'             = 'Services Sector XX Population',
  'tertiary_enrol_gross.l:population.l' = 'Tertiary Enrolment XX Population',
  'tertiary_enrol_gross:population.l'   = 'Tertiary Enrolment XX Population',
  'tertiary_enrol.norm:population.l'    = 'Tertiary Enrolment XX Population'
)
vl.bea <- gsub('XX', '$\\times$', vl.bea, fixed = TRUE)
vl.bea.wb <- AddBetweenTerms(vl.bea)
vl.bea <- DuplicateInteractions(vl.bea)
vl.bea.wb <- DuplicateInteractions(vl.bea.wb)
