# This file defines subsetting functions. It requires default.data to be set.

# Subsets according to World Bank high-income indicator
Hi99 <- . %>% filter(high.income1999)
Hi06 <- . %>% filter(high.income2006)
Li99 <- . %>% filter(!high.income1999)
Li06 <- . %>% filter(!high.income2006)

# EU joiners in the sample
joiners <- default.data %>%
  group_by(country.iso3) %>%
  filter((sum(eu) != n() & sum(eu) != 0)) %>%
  ungroup() %>%
  filter(eu == 1) %>%
  arrange(year) %>%
  group_by(country.iso3) %>%
  summarise(joined = first(year)) %>%
  arrange(joined) %$%
  country.iso3

# Subsets: all-time EU - all-time nonEU
Eu1 <- . %>% filter(eu == 1)
Eu0 <- . %>% filter(eu == 0)
EuA <- . %>% filter(!(country.iso3 %in% joiners) & eu == 1)
EuN <- . %>% filter(!(country.iso3 %in% joiners) & eu == 0)
EuJ <- . %>% filter(country.iso3 %in% joiners)

# Subsets: Schengen OR EU member
Fr1 <- . %>% filter(schengen.implemented == 1 | eu == 1)
Fr0 <- . %>% filter(schengen.implemented == 0 & eu == 0)

# Subsets: cities
BigInd <- . %>%
  group_by(country.iso3, city) %>%
  mutate(city.pop.avg = mean(pop.city, na.rm = TRUE)) %>%
  group_by(country.iso3) %>%
  mutate(is.biggest.city = city.pop.avg == max(city.pop.avg)) %>%
  ungroup() %>%
  select(-city.pop.avg)
Big   <- . %>% BigInd() %>% filter(is.biggest.city)  %>% select(-is.biggest.city)
NoBig <- . %>% BigInd() %>% filter(!is.biggest.city) %>% select(-is.biggest.city)

Cap   <- .  %>% filter(is.capital)
NoCap <- .  %>% filter(!is.capital)
